%global processor_arch arm
%global target         %{processor_arch}-none-eabi

Name:           %{target}-binutils-cs
Epoch:          1
Version:        2.44
Release:        2%{?dist}
Summary:        GNU Binutils for cross-compilation for %{target} target
# Most of the sources are licensed under GPLv3+ with these exceptions:
# LGPLv2+ bfd/hosts/x86-64linux.h, include/demangle.h, include/xregex2.h,
# GPLv2+  gprof/cg_print.h
# BSD     gprof/cg_arcs.h, gprof/utils.c, ld/elf-hints-local.h,
# Public Domain libiberty/memmove.c
# Automatically converted from old format: GPLv2+ and GPLv3+ and LGPLv2+ and BSD - review is highly recommended.
License:        GPL-2.0-or-later AND GPL-3.0-or-later AND LicenseRef-Callaway-LGPLv2+ AND LicenseRef-Callaway-BSD
URL:            http://www.codesourcery.com/sgpp/lite/%{processor_arch}

Source0:        https://ftp.gnu.org/pub/gnu/binutils/binutils-%{version}.tar.xz

Source1:        README.fedora
BuildRequires:  gcc flex bison
BuildRequires:  autoconf
BuildRequires:  texinfo texinfo-tex perl-podlators
BuildRequires:  make zlib-devel
Provides:       %{target}-binutils = %{version}

%if 0%{?fedora} > 39
# as per https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
# ppl-devel is no longer available for 32bit, so we have to skip it too
ExcludeArch:    %{ix86}
%endif

%description
This is a cross-compilation version of GNU Binutils, which can be used to
assemble and link binaries for the %{target} platform.  

Binutils is a collection of binary utilities, including ar (for
creating, modifying and extracting from archives), as (a family of GNU
assemblers), gprof (for displaying call graph profile data), ld (the
GNU linker), nm (for listing symbols from object files), objcopy (for
copying and translating object files), objdump (for displaying
information from object files), ranlib (for generating an index for
the contents of an archive), readelf (for displaying detailed
information about binary files), size (for listing the section sizes
of an object or archive file), strings (for listing printable strings
from files), strip (for discarding symbols), and addr2line (for
converting addresses to file and line).

%prep
%autosetup -p1 -n binutils-%{version}
cp -p %{SOURCE1} .
rm -rf gdb sim

%build
# We call configure directly rather than via macros, thus if
# we are using LTO, we have to manually fix the broken configure
# scripts
pushd libiberty
#autoconf -f
popd
%if 0%{?fedora} || 0%{?rhel} > 8
[ %{_lto_cflags}x != x ] && %{_fix_broken_configure_for_lto}
%endif

./configure CFLAGS="$RPM_OPT_FLAGS" \
            --target=%{target} \
            --enable-interwork \
            --enable-multilib \
            --enable-plugins \
            --disable-nls \
            --disable-shared \
            --disable-threads \
            --with-gcc --with-gnu-as --with-gnu-ld \
            --with-system-zlib \
            --prefix=%{_prefix} \
            --libdir=%{_libdir} \
            --mandir=%{_mandir} \
            --infodir=%{_infodir} \
            --with-docdir=share/doc/%{name} \
            --disable-werror \
            --with-pkgversion="Fedora %{version}-%{release}" \
            --with-bugurl="https://bugzilla.redhat.com/"
make %{?_smp_mflags}

%check
%ifnarch s390x
make check
%endif
echo "completed"

%install
make install DESTDIR=$RPM_BUILD_ROOT
# these are for win targets only
rm    $RPM_BUILD_ROOT%{_mandir}/man1/%{target}-{dlltool,windres}.1
# we don't want these as we are a cross version
rm -r $RPM_BUILD_ROOT%{_infodir}
rm    $RPM_BUILD_ROOT%{_libdir}/lib*.a $RPM_BUILD_ROOT%{_libdir}/bfd-plugins/libdep* ||:


%files
%license COPYING*
%doc ChangeLog README.fedora
%{_prefix}/%{target}
%{_bindir}/%{target}-*
%{_mandir}/man1/%{target}-*.1.gz


%changelog
* Wed Feb 19 2025 Michal Hlavinka <mhlavink@redhat.com> - 1:2.44-2
- build for epel10, trim changelog

* Tue Feb 11 2025 Michal Hlavinka <mhlavink@redhat.com> - 1:2.44-1
- updated to 2.44

* Thu Jan 16 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1:2.43-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Tue Sep 03 2024 Michal Hlavinka <mhlavink@redhat.com> - 1:2.43-1
- updated to 2.43

* Wed Aug 28 2024 Miroslav Suchý <msuchy@redhat.com> - 1:2.42-4
- convert license to SPDX

* Wed Jul 17 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:2.42-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Fri Mar 08 2024 Michal Hlavinka <mhlavink@redhat.com> - 1:2.42-2
- drop i686 build as ppl-devel.i686 is no longer available

* Wed Mar 06 2024 Michal Hlavinka <mhlavink@redhat.com> - 1:2.42-1
- updated to 2.42

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:2.41-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1:2.41-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

